@@ -17,16 +17,16 @@ class Analytics:
         start = time()
         response = self.get_response(request)
 
-        json = {
+        data = {
             'api_key': self.api_key,
             'hostname': request.get_host(),
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
             'status': response.status_code,
-            'framework': 9,
+            'framework': 'Django',
             'response_time': int((time() - start) * 1000),
         }
 
-        threading.Thread(target=log_request, args=(json,)).start()
+        threading.Thread(target=log_request, args=(data,)).start()
         return response
\ No newline at end of file
