@@ -22,15 +22,15 @@ class Analytics(BaseHTTPMiddleware):
         start = time()
         response = call_next(request)
 
-        json = {
+        data = {
             'api_key': self.api_key,
             'hostname': request.host,
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
             'status': response.status_code,
-            'framework': 1,
+            'framework': 'Flask',
             'response_time': int((time() - start) * 1000),
         }
-        threading.Thread(target=log_request, args=(json,)).start()
+        threading.Thread(target=log_request, args=(data,)).start()
         return response
